pub struct CodeBlock<'a> {
pub source: CowStr<'a>,
pub language: Option<CowStr<'a>>,
}Expand description
A code block from a Markdown document’s Frontmatter.
Fields
source: CowStr<'a>The contents of the code block.
language: Option<CowStr<'a>>The language of the code block, which is the identifier following the three backticks in a fenced Markdown code block.